"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SQSHelper = void 0;
const AWS = require("aws-sdk");
const typescript_helper_functions_1 = require("typescript-helper-functions");
/**
 * SQS Helper
 */
class SQSHelper extends typescript_helper_functions_1.BaseClass {
    /**
     * Initializes new instance of SQSHelper
     * @param logger {ILogger} Injected logger
     * @param repository {AWS.SQS} Injected Repository. A new repository will be created if not supplied
     * @param options {AWS.SQS.ClientConfiguration} Injected configuration if a Repository is supplied
     */
    constructor(logger, repository, options) {
        super(logger);
        this.Repository = repository || new AWS.SQS(options);
    }
    CreateQueueAsync(queueName, attributes) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${SQSHelper.name}.${this.CreateQueueAsync.name}`;
            this.LogHelper.LogInputs(action, { queueName, attributes });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(queueName)) {
                throw new Error(`[${action}]-Must supply queueName`);
            }
            // create params object
            const params = {
                Attributes: attributes,
                QueueName: queueName,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.createQueue(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
    DeleteMessageAsync(queueUrl, receiptHandle) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${SQSHelper.name}.${this.DeleteMessageAsync.name}`;
            this.LogHelper.LogInputs(action, { queueUrl, receiptHandle });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
                throw new Error(`[${action}]-Must supply queueUrl`);
            }
            if (this.ObjectOperations.IsNullOrWhitespace(receiptHandle)) {
                throw new Error(`[${action}]-Must supply receiptHandle`);
            }
            // create params object
            const params = {
                QueueUrl: queueUrl,
                ReceiptHandle: receiptHandle,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.deleteMessage(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
    DeleteMessagesAsync(queueUrl, receiptHandles) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${SQSHelper.name}.${this.DeleteMessagesAsync.name}`;
            this.LogHelper.LogInputs(action, { queueUrl, receiptHandles });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
                throw new Error(`[${action}]-Must supply queueUrl`);
            }
            if (!receiptHandles || receiptHandles.length === 0) {
                throw new Error(`[${action}]-Must supply at least one receiptHandle`);
            }
            if (receiptHandles.length > 10) {
                throw new Error(`[${action}]-Can only supply up to 10 receiptHandles`);
            }
            // create entries to delete
            const entries = [];
            for (const handle of receiptHandles) {
                entries.push({ Id: handle, ReceiptHandle: handle });
            }
            // create params object
            const params = {
                Entries: entries,
                QueueUrl: queueUrl,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.deleteMessageBatch(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
    DeleteQueueAsync(queueUrl) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${SQSHelper.name}.${this.DeleteQueueAsync.name}`;
            this.LogHelper.LogInputs(action, { queueUrl });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
                throw new Error(`[${action}]-Must supply queueUrl`);
            }
            // create params object
            const params = {
                QueueUrl: queueUrl,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.deleteQueue(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
    GetNumberOfMessagesOnQueueAsync(queueUrl) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${SQSHelper.name}.${this.GetNumberOfMessagesOnQueueAsync.name}`;
            this.LogHelper.LogInputs(action, { queueUrl });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
                throw new Error(`[${action}]-Must supply queueUrl`);
            }
            const params = {
                QueueUrl: queueUrl,
                AttributeNames: ['ApproximateNumberOfMessages'],
            };
            this.LogHelper.LogRequest(action, params);
            const response = yield this.Repository.getQueueAttributes(params).promise();
            this.LogHelper.LogResponse(action, response);
            let messages = '';
            if (response && response.Attributes) {
                messages = response.Attributes['ApproximateNumberOfMessages'];
            }
            return parseInt(messages, 10);
        });
    }
    GetQueueAttributesAsync(queueUrl) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${SQSHelper.name}.${this.GetQueueAttributesAsync.name}`;
            this.LogHelper.LogInputs(action, { queueUrl });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
                throw new Error(`[${action}]-Must supply queueUrl`);
            }
            const params = {
                QueueUrl: queueUrl,
                AttributeNames: ['ALL'],
            };
            this.LogHelper.LogRequest(action, params);
            const response = yield this.Repository.getQueueAttributes(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response.Attributes || {};
        });
    }
    PurgeQueueAsync(queueUrl) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${SQSHelper.name}.${this.PurgeQueueAsync.name}`;
            this.LogHelper.LogInputs(action, { queueUrl });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
                throw new Error(`[${action}]-Must supply queueUrl`);
            }
            // create params object
            const params = {
                QueueUrl: queueUrl,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.purgeQueue(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
    ReceiveAllMessagesAsync(queueUrl, visibilityTimeout, attributeNames, messageAttributeNames) {
        return __awaiter(this, void 0, void 0, function* () {
            let allMessages = [];
            while (true) {
                const messages = yield this.ReceiveMessagesAsync(queueUrl, 10, visibilityTimeout, attributeNames, messageAttributeNames);
                if (!messages || !messages.Messages || messages.Messages.length < 1) {
                    break;
                }
                allMessages = allMessages.concat(messages.Messages);
            }
            return allMessages;
        });
    }
    ReceiveMessagesAsync(queueUrl, maxNumberOfMessages, visibilityTimeout, attributeNames, messageAttributeNames) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${SQSHelper.name}.${this.ReceiveMessagesAsync.name}`;
            this.LogHelper.LogInputs(action, { queueUrl, maxNumberOfMessages, visibilityTimeout, attributeNames, messageAttributeNames });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
                throw new Error(`[${action}]-Must supply queueUrl`);
            }
            // set defaults
            if (!maxNumberOfMessages) {
                maxNumberOfMessages = 10;
            }
            if (!visibilityTimeout) {
                visibilityTimeout = 10;
            }
            if (!attributeNames || attributeNames.length === 0) {
                attributeNames = ['ALL'];
            }
            // create params object
            const params = {
                AttributeNames: attributeNames,
                MaxNumberOfMessages: maxNumberOfMessages,
                MessageAttributeNames: messageAttributeNames,
                QueueUrl: queueUrl,
                VisibilityTimeout: visibilityTimeout,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.receiveMessage(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
    SendMessageAsync(queueUrl, messageBody, delaySeconds, messageAttributes) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${SQSHelper.name}.${this.SendMessageAsync.name}`;
            this.LogHelper.LogInputs(action, { queueUrl, messageBody, delaySeconds, messageAttributes });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
                throw new Error(`[${action}]-Must supply queueUrl`);
            }
            if (this.ObjectOperations.IsNullOrWhitespace(messageBody)) {
                throw new Error(`[${action}]-Must supply messageBody`);
            }
            // set defaults
            if (!delaySeconds) {
                delaySeconds = 0;
            }
            // create params object
            const params = {
                DelaySeconds: delaySeconds,
                MessageAttributes: messageAttributes,
                MessageBody: messageBody,
                QueueUrl: queueUrl,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.sendMessage(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
    SendMessagesAsync(queueUrl, entries) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${SQSHelper.name}.${this.SendMessagesAsync.name}`;
            this.LogHelper.LogInputs(action, { queueUrl });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
                throw new Error(`[${action}]-Must supply queueUrl`);
            }
            if (!entries || entries.length === 0) {
                throw new Error(`[${action}]-Must supply at least one entry`);
            }
            // create params object
            const params = {
                Entries: entries,
                QueueUrl: queueUrl,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.sendMessageBatch(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
}
exports.SQSHelper = SQSHelper;
//# sourceMappingURL=helper.js.map